@@ -1,10 +1,10 @@
-__version__ = "0.4.24"
+__version__ = "0.4.25"
 __git_commiter_name__ = "Arnon Yaari"
 __git_commiter_email__ = "arnony@infinidat.com"
-__git_branch__ = '(detached from v0.4.24)'
+__git_branch__ = '(detached from v0.4.25)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = '9614dbdd43459501612b3c3dca4bb803b184142e'
-__git_head_subject__ = 'Finished release v0.4.24.'
+__git_head_hash__ = 'd0715288638ad7985574ff7b55a930c10709d70f'
+__git_head_subject__ = 'fix PyPI.get_all_packages'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
